%   [m,T]=Ret_periodGRT(Md,Mu,dM,Mmin,lamb,eps,b,Mmax)
%
% EVALUATES THE MEAN RETURN PERIOD VALUES USING THE UPPER-BOUNDED G-R LED 
%   MAGNITUDE DISTRIBUTION MODEL.
%
% AUTHOR: S. Lasocki 06/2014 within IS-EPOS project.
%
% DESCRIPTION: The assumption on the upper-bounded Gutenberg-Richter 
% relation leads to the upper truncated exponential distribution to model 
% magnitude distribution from and above the catalog completness level 
% Mmin. The shape parameter of this distribution, consequently the G-R
% b-value and the end-point of the distriobution Mmax as well as the
% activity rate of M>=Mmin events are calculated at start-up of the 
% stationary hazard assessment services in the upper-bounded 
% Gutenberg-Richter estimation mode.
% 
% The mean return period of magnitude M is the average elapsed time between
% the consecutive earthquakes of magnitude M.   
% The mean return periods are calculated for magnitude starting from Md up
% to Mu with step dM.
%
% INPUT:
%   t - vector of earthquake occurrence times
%   M - vector of earthquake magnitudes
%   Md - starting magnitude for return period calculations
%   Mu - ending magnitude for return period calculations
%   dM - magnitude step for return period calculations 
%   Mmin - lower bound of the distribution - catalog completeness level
%   lamb - mean activity rate for events M>=Mmin
%   eps - length of the round-off interval of magnitudes.
%   b - Gutenberg-Richter b-value
%   Mmax - upper limit of magnitude distribution

% OUTPUT:
%   m - vector of independent variable (magnitude) m=(Md:dM:Mu)
%   T - vector od mean return periods of the same length as m
%
% LICENSE
%     This file is a part of the IS-EPOS e-PLATFORM.
%
%     This is free software: you can redistribute it and/or modify it under 
%     the terms of the GNU General Public License as published by the Free 
%     Software Foundation, either version 3 of the License, or 
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 


function [m,T]=Ret_periodGRT(Md,Mu,dM,Mmin,lamb,eps,b,Mmax)

% -------------- VALIDATION RULES -------------  K_21NOV2016
 if dM<=0;error('Magnitude Step must be greater than 0');end
%----------------------------------------------------------

if Md<Mmin; Md=Mmin;end
if Mu>Mmax; Mu=Mmax;end
m=(Md:dM:Mu)';
beta=b*log(10);
T=1/lamb./(1-Cdfgr(m,beta,Mmin-eps/2,Mmax));
end


function [y]=Cdfgr(t,beta,Mmin,Mmax)

%CDF of the truncated upper-bounded exponential distribution (truncated G-R
% model
% Mmin - catalog completeness level
% Mmax - upper limit of the distribution
% beta - the distribution parameter
% t - vector of magnitudes (independent variable)
% y - CDF vector

mian=(1-exp(-beta*(Mmax-Mmin)));
y=(1-exp(-beta*(t-Mmin)))/mian;
idx=find(y>1);
y(idx)=ones(size(idx));
end


